@@ -1,11 +1,16 @@
 # coding=utf-8
-"""GeoIP lookup module"""
-# Copyright 2011, Dimitri Molenaars, TyRope.nl,
-# Copyright © 2013, Elad Alfassa <elad@fedoraproject.org>
-# Licensed under the Eiffel Forum License 2.
+"""
+ip.py - Sopel GeoIP Lookup Module
+Copyright 2011, Dimitri Molenaars, TyRope.nl,
+Copyright © 2013, Elad Alfassa <elad@fedoraproject.org>
+Licensed under the Eiffel Forum License 2.
+
+https://sopel.chat
+"""
 
 from __future__ import unicode_literals, absolute_import, print_function, division
 
+import logging
 import os
 import socket
 import tarfile
@@ -13,8 +18,8 @@ import tarfile
 import geoip2.database
 
 from sopel.config.types import FilenameAttribute, StaticSection
-from sopel.logger import get_logger
 from sopel.module import commands, example
+from sopel.tools import web
 
 urlretrieve = None
 try:
@@ -28,12 +33,13 @@ except ImportError:
     except ImportError:
         pass
 
-LOGGER = get_logger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 
 class GeoipSection(StaticSection):
     GeoIP_db_path = FilenameAttribute('GeoIP_db_path', directory=True)
-    """Path of the directory containing the GeoIP db files."""
+    """Path of the directory containing the GeoIP database files."""
 
 
 def configure(config):
@@ -52,7 +58,7 @@ def setup(bot):
 
 
 def _decompress(source, target, delete_after_decompression=True):
-    """ Decompress just the database from the archive """
+    """Decompress just the database from the archive"""
     # https://stackoverflow.com/a/16452962
     tar = tarfile.open(source)
     for member in tar.getmembers():
@@ -64,7 +70,7 @@ def _decompress(source, target, delete_after_decompression=True):
 
 
 def _find_geoip_db(bot):
-    """ Find the GeoIP database """
+    """Find the GeoIP database"""
     config = bot.config
     if config.ip.GeoIP_db_path:
         cities_db = os.path.join(config.ip.GeoIP_db_path, 'GeoLite2-City.mmdb')
@@ -73,8 +79,8 @@ def _find_geoip_db(bot):
             return config.ip.GeoIP_db_path
         else:
             LOGGER.warning(
-                'GeoIP path configured but DB not found in configured path'
-            )
+                'GeoIP path configured but DB not found in configured path')
+
     if (os.path.isfile(os.path.join(config.core.homedir, 'GeoLite2-City.mmdb')) and
             os.path.isfile(os.path.join(config.core.homedir, 'GeoLite2-ASN.mmdb'))):
         return config.core.homedir
@@ -82,13 +88,23 @@ def _find_geoip_db(bot):
             os.path.isfile(os.path.join('/usr/share/GeoIP', 'GeoLite2-ASN.mmdb'))):
         return '/usr/share/GeoIP'
     elif urlretrieve:
-        LOGGER.warning('Downloading GeoIP database')
+        LOGGER.info('Downloading GeoIP database')
         bot.say('Downloading GeoIP database, please wait...')
-        geolite_urls = [
-            'https://geolite.maxmind.com/download/geoip/database/GeoLite2-City.tar.gz',
-            'https://geolite.maxmind.com/download/geoip/database/GeoLite2-ASN.tar.gz'
-        ]
+
+        common_params = {'license_key': 'JXBEmLjOzislFnh4', 'suffix': 'tar.gz'}
+        base_url = 'https://download.maxmind.com/app/geoip_download'
+        geolite_urls = []
+
+        for edition in ['ASN', 'City']:
+            geolite_urls.append(
+                '{base}?{params}'.format(
+                    base=base_url,
+                    params=web.urlencode(dict(common_params, **{'edition_id': 'GeoLite2-%s' % edition})),
+                )
+            )
+
         for url in geolite_urls:
+            LOGGER.debug('GeoIP Source URL: %s', url)
             full_path = os.path.join(config.core.homedir, url.split("/")[-1])
             urlretrieve(url, full_path)
             _decompress(full_path, config.core.homedir)
@@ -99,9 +115,10 @@ def _find_geoip_db(bot):
 
 @commands('iplookup', 'ip')
 @example('.ip 8.8.8.8',
-         r'\[IP\/Host Lookup\] Hostname: \S*dns\S*\.google\S* \| Location: United States \| ISP: AS15169 Google LLC',
+         r'\[IP\/Host Lookup\] Hostname: \S*dns\S*\.google\S* \| Location: United States \| ISP: AS15169 \S+',
          re=True,
-         ignore='Downloading GeoIP database, please wait...')
+         ignore='Downloading GeoIP database, please wait...',
+         online=True)
 def ip(bot, trigger):
     """IP Lookup tool"""
     # Check if there is input at all
